# This script produces figure in the data application section

#### set up ####
knitr::opts_chunk$set(echo = FALSE)

rm(list = ls())
library("survival")
library("ggplot2")
library(ggpubr)
library("cubature")
library(tidyverse)
library(dplyr)
library(here)
library(risksetROC)
library(mgcv)
library(scam)
library("clinfun")
library(glmnet)
library(kableExtra)
theme_set(theme_minimal())
cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

# set the seed
set.seed(512)


#### load data ####
load(here("Data/ApplResult.RData"))

# format
appl_auc <- bind_rows(tvauc_in_df_gam %>% mutate(sample = "In-sample"),
                      tvauc_out_df_gam %>% mutate(sample = "Out-of-sample"), 
                      tvauc_in_df_lin %>% mutate(sample = "In-sample"), 
                      tvauc_out_df_lin %>% mutate(sample = "Out-of-sample")) %>%
  mutate(model = factor(model, levels = c("GAM", "Lin"),
                        labels = c("ACM","LCM"))) %>%
  pivot_longer(c("HZ", "NP", "SNP"), names_to = "Estimator", values_to = "AUC") %>%
  mutate(Estimator=factor(Estimator, levels = c("HZ", "NP", "SNP"),
                          labels = c("Semi-parametric",
                                     "Non-parametric",
                                     "Smoothed non-parametric")))
# figure of auc
appl_auc %>% 
  ggplot(aes(x = time, y = AUC, col = model, linetype = sample, linewidth = sample,
             alpha = sample))+
  geom_smooth(se = F, formula = y~s(x,  k=30, bs = "cs"),
              na.rm = T, method = "gam")+
  labs(x = "Time", y = "AUC",
       linetype = "Sample", color = "Model")+
  facet_grid(~Estimator)+
  scale_color_manual(values = cbPalette)+
  scale_linewidth_manual(values = c(0.6, 1.5), guide = "none")+
  scale_alpha_manual(values = c(0.5, 1), guide = "none")
ggsave(filename = here("Figs/appl_auc.pdf"), 
       width=12, height=4, bg="white", dpi = 300)


# figure of concordance
appl_c <- bind_rows(df_c_gam, df_c_lin) %>% 
  mutate(type = ifelse(estimator %in% c("Harrell", "NP","SNP"), 
                       "Non-parametric", "Semi-parametric")) %>% 
  mutate(model = factor(model, levels=c("Lin", "GAM"), 
                        labels = c("LCM", "ACM"))) %>%
  mutate(type = factor(type, levels = c("Semi-parametric", "Non-parametric"))) %>%
  rename(Sample=estimand) 

appl_c%>%
  ggplot() + 
  geom_boxplot(aes(x=model,y=Freq, fill=Sample)) + 
  facet_wrap(~type+estimator, nrow = 1)+
  labs(x = "Model", y = "Concordance")+
  scale_fill_manual(values = cbPalette)+
  scale_color_manual(values = cbPalette)
ggsave(filename = here("Figs/appl_c.pdf"), 
       width=12, height=4, bg="white", dpi = 300)
