
# This script produce other figures that are in the supplemental material


#### set up ####

rm(list = ls())
library("survival")
library("ggplot2")
library(ggpubr)
library("cubature")
library(tidyverse)
library(dplyr)
library(here)
library(risksetROC)
library(mgcv)
library(scam)
library("clinfun")
library(glmnet)
library(kableExtra)
theme_set(theme_minimal())
cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

# set the seed
set.seed(512)


#### simulation data distribution ####

load(here("Data/SimNoiseTrainData.RData"))
load(here("Data/SimContamTrainData.RData"))

all_train_data <- bind_rows(bind_rows(train_list), bind_rows(train_list2))

# proportion of event and censoring
table(all_train_data$event)
table(all_train_data$event)/nrow(all_train_data)

# median event time
median(all_train_data$time[all_train_data$event==1])

# figure of distribution of event and censoring
all_train_data %>%
  mutate(event=ifelse(event==0, "Censor", "Event")) %>%
  ggplot()+
  geom_histogram(aes(x=time, y=after_stat(ndensity)), bins=50)+
  facet_wrap(~event)+
  labs(x="Time", y= "Density")
ggsave(filename = here("Figs/SimDataDensity.pdf"),
       width=8, height=4, bg="white", dpi = 300)

#### Data application TV-AUC scatter plot ####

load(here("Data/ApplResult.RData"))

appl_auc <- bind_rows(tvauc_in_df_gam %>% mutate(sample = "In-sample"),
                      tvauc_out_df_gam %>% mutate(sample = "Out-of-sample"), 
                      tvauc_in_df_lin %>% mutate(sample = "In-sample"), 
                      tvauc_out_df_lin %>% mutate(sample = "Out-of-sample")) %>%
  mutate(model = factor(model, levels = c("GAM", "Lin"),
                        labels = c("ACM","LCM"))) %>%
  pivot_longer(c("HZ", "NP", "SNP"), names_to = "Estimator", values_to = "AUC") %>%
  mutate(Estimator=factor(Estimator, levels = c("HZ", "NP", "SNP"),
                          labels = c("Semi-parametric",
                                     "Non-parametric",
                                     "Smoothed non-parametric")))


appl_auc %>% filter(sample == "In-sample") %>%
  mutate(iter=factor(iter, levels = 1:10)) %>%
  ggplot(aes(x=time, y=AUC, color = iter))+
  geom_point(size = 0.5, alpha = 0.8)+
  facet_wrap(~Estimator, nrow = 1)+
  labs(x = "Time", y = "AUC", color = "Fold")  +
  scale_color_manual(values =  c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442",
                                 "#0072B2", "#D55E00", "#CC79A7", "#44AA99", "#88CCEE")
  )
ggsave(filename = here("Figs/DataApplAUCScatter.pdf"),
       width=12, height=4, bg="white", dpi = 300)

